==> tdeedu-R14.0.0-x86_64-ifx.txz: install/doinst.sh <==
( cd usr/lib64 ; rm -rf libtdeeducore.so.1 )
( cd usr/lib64 ; ln -sf libtdeeducore.so.1.2.0 libtdeeducore.so.1 )
( cd usr/lib64 ; rm -rf libtdeeducore.so )
( cd usr/lib64 ; ln -sf libtdeeducore.so.1.2.0 libtdeeducore.so )
( cd usr/lib64 ; rm -rf libtdeeduui.so.3 )
( cd usr/lib64 ; ln -sf libtdeeduui.so.3.0.5 libtdeeduui.so.3 )
( cd usr/lib64 ; rm -rf libtdeeduui.so )
( cd usr/lib64 ; ln -sf libtdeeduui.so.3.0.5 libtdeeduui.so )
( cd usr/lib64 ; rm -rf libtdeeduplot.so.1 )
( cd usr/lib64 ; ln -sf libtdeeduplot.so.1.2.0 libtdeeduplot.so.1 )
( cd usr/lib64 ; rm -rf libtdeeduplot.so )
( cd usr/lib64 ; ln -sf libtdeeduplot.so.1.2.0 libtdeeduplot.so )
( cd usr/lib64 ; rm -rf libextdate.so.1 )
( cd usr/lib64 ; ln -sf libextdate.so.1.2.0 libextdate.so.1 )
( cd usr/lib64 ; rm -rf libextdate.so )
( cd usr/lib64 ; ln -sf libextdate.so.1.2.0 libextdate.so )
( cd usr/lib64 ; rm -rf libkiten.so.1 )
( cd usr/lib64 ; ln -sf libkiten.so.1.0.0 libkiten.so.1 )
( cd usr/lib64 ; rm -rf libkiten.so )
( cd usr/lib64 ; ln -sf libkiten.so.1.0.0 libkiten.so )
( cd usr/lib64 ; rm -rf libkvoctraincore.so.0 )
( cd usr/lib64 ; ln -sf libkvoctraincore.so.0.0.0 libkvoctraincore.so.0 )
( cd usr/lib64 ; rm -rf libkvoctraincore.so )
( cd usr/lib64 ; ln -sf libkvoctraincore.so.0.0.0 libkvoctraincore.so )
( cd usr/share/doc/tde/HTML/en/blinken ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/blinken ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kalzium ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kalzium ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kanagram ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kanagram ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kbruch ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kbruch ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/keduca ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/keduca ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kgeography ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kgeography ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/khangman ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/khangman ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kig ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kig ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kiten ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kiten ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/klatin ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/klatin ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/klettres ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/klettres ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kmplot ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kmplot ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kpercentage ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kpercentage ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kstars ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kstars ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/ktouch ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/ktouch ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kturtle ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kturtle ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kverbos ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kverbos ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kvoctrain ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kvoctrain ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kwordquiz ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kwordquiz ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/bin ; rm -rf lx200classic )
( cd usr/bin ; ln -sf lx200generic lx200classic )
( cd usr/bin ; rm -rf lx200autostar )
( cd usr/bin ; ln -sf lx200generic lx200autostar )
( cd usr/bin ; rm -rf lx200_16 )
( cd usr/bin ; ln -sf lx200generic lx200_16 )
( cd usr/bin ; rm -rf lx200gps )
( cd usr/bin ; ln -sf lx200generic lx200gps )

==> tdeedu-14.0.11-x86_64-ifx.txz: install/doinst.sh <==

# Update the desktop database:
/usr/bin/update-desktop-database ./usr/share/applications

# Update hicolor theme cache:
/usr/bin/gtk-update-icon-cache -f -t ./usr/share/icons/hicolor

# Update the mime database:
/usr/bin/update-mime-database -Vn usr/share/mime

( cd usr/bin ; rm -rf lx200_16 )
( cd usr/bin ; ln -sf lx200generic lx200_16 )
( cd usr/bin ; rm -rf lx200autostar )
( cd usr/bin ; ln -sf lx200generic lx200autostar )
( cd usr/bin ; rm -rf lx200classic )
( cd usr/bin ; ln -sf lx200generic lx200classic )
( cd usr/bin ; rm -rf lx200gps )
( cd usr/bin ; ln -sf lx200generic lx200gps )
( cd usr/lib64 ; rm -rf libextdate.so )
( cd usr/lib64 ; ln -sf libextdate.so.1 libextdate.so )
( cd usr/lib64 ; rm -rf libextdate.so.1 )
( cd usr/lib64 ; ln -sf libextdate.so.1.2.0 libextdate.so.1 )
( cd usr/lib64 ; rm -rf libkiten.so )
( cd usr/lib64 ; ln -sf libkiten.so.1 libkiten.so )
( cd usr/lib64 ; rm -rf libkiten.so.1 )
( cd usr/lib64 ; ln -sf libkiten.so.1.0.0 libkiten.so.1 )
( cd usr/lib64 ; rm -rf libkvoctraincore.so )
( cd usr/lib64 ; ln -sf libkvoctraincore.so.0 libkvoctraincore.so )
( cd usr/lib64 ; rm -rf libkvoctraincore.so.0 )
( cd usr/lib64 ; ln -sf libkvoctraincore.so.0.0.0 libkvoctraincore.so.0 )
( cd usr/lib64 ; rm -rf libtdeeducore.so )
( cd usr/lib64 ; ln -sf libtdeeducore.so.1 libtdeeducore.so )
( cd usr/lib64 ; rm -rf libtdeeducore.so.1 )
( cd usr/lib64 ; ln -sf libtdeeducore.so.1.2.0 libtdeeducore.so.1 )
( cd usr/lib64 ; rm -rf libtdeeduplot.so )
( cd usr/lib64 ; ln -sf libtdeeduplot.so.1 libtdeeduplot.so )
( cd usr/lib64 ; rm -rf libtdeeduplot.so.1 )
( cd usr/lib64 ; ln -sf libtdeeduplot.so.1.2.0 libtdeeduplot.so.1 )
( cd usr/lib64 ; rm -rf libtdeeduui.so )
( cd usr/lib64 ; ln -sf libtdeeduui.so.3 libtdeeduui.so )
( cd usr/lib64 ; rm -rf libtdeeduui.so.3 )
( cd usr/lib64 ; ln -sf libtdeeduui.so.3.0.5 libtdeeduui.so.3 )
( cd usr/share/doc/tde/HTML/en/blinken ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/blinken ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kalzium ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kalzium ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kanagram ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kanagram ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kbruch ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kbruch ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/keduca ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/keduca ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kgeography ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kgeography ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/khangman ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/khangman ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kig ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kig ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kiten ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kiten ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/klatin ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/klatin ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/klettres ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/klettres ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kmplot ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kmplot ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kpercentage ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kpercentage ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kstars ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kstars ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/ktouch ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/ktouch ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kturtle ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kturtle ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kverbos ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kverbos ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kvoctrain ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kvoctrain ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kwordquiz ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kwordquiz ; ln -sf /usr/share/doc/tde/HTML/en/common common )
